package tech.mercantec.easyeat

import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.widget.ArrayAdapter
import android.widget.Button
import android.widget.EditText
import android.widget.ImageButton
import android.widget.LinearLayout
import android.widget.Spinner
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContentProviderCompat.requireContext
import tech.mercantec.easyeat.models.Ingredient

class CreateDishActivity : AppCompatActivity() {

    private lateinit var ingredientContainer: LinearLayout

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_create_dish_form)

        ingredientContainer = findViewById(R.id.ingredientContainer)
        val addButton: Button = findViewById(R.id.addIngredientButton)

        // Add the first ingredient row manually at startup
        addIngredientRow()

        // Set up button to add new rows
        addButton.setOnClickListener {
            addIngredientRow()
        }

        val saveButton: Button = findViewById(R.id.saveDishButton)
        saveButton.setOnClickListener {
            val ingredientList = collectIngredients()

            val name = findViewById<EditText>(R.id.dishName).text.toString().trim()
            val description = findViewById<EditText>(R.id.dishDescription).text.toString().trim()
            val instructions = findViewById<EditText>(R.id.instructions).text.toString().trim()
            // Debug/log example
            for (ingredient in ingredientList) {
                Log.d("INGREDIENT", "Name: ${ingredient.Element}, Amount: ${ingredient.Amount}, Unit: ${ingredient.Unit}")
            }
        }

    }

    private fun addIngredientRow() {
        val inflater = LayoutInflater.from(this)
        val ingredientRow = inflater.inflate(R.layout.activity_create_dish_ingredient_row, null)
        val spinnerMeasurements = ingredientRow.findViewById<Spinner>(R.id.measurementsDropDown)
        spinnerMeasurements.adapter = ArrayAdapter(
            this,
            android.R.layout.simple_spinner_item,
            listOf("g", "kg", "ml", "l", "tsp", "tbsp", "cup", "pcs", "pinch", "dash")
        )

        // Handle remove button in each row
        val removeButton: ImageButton = ingredientRow.findViewById(R.id.removeButton)
        removeButton.setOnClickListener {
            ingredientContainer.removeView(ingredientRow)
        }

        ingredientContainer.addView(ingredientRow)
    }

    private fun collectIngredients(): List<Ingredient> {
        val ingredients = mutableListOf<Ingredient>()

        for (i in 0 until ingredientContainer.childCount) {
            val ingredientView = ingredientContainer.getChildAt(i)

            // Find views inside this ingredient row

            val ingredientEditText = ingredientView.findViewById<EditText>(R.id.ingredientNameEditText)
            val amountEditText = ingredientView.findViewById<EditText>(R.id.ingredientAmountEditText)
            val spinner = ingredientView.findViewById<Spinner>(R.id.measurementsDropDown)

            val element = ingredientEditText.text.toString().trim()
            val amount = amountEditText.text.toString().trim()
            val unit = spinner.selectedItem.toString()

            // Optional: Only add non-empty rows
            if (element.isNotEmpty() && amount.isNotEmpty()) {
                ingredients.add(Ingredient(Element = element, Amount = amount.toInt(), Unit = unit))
            }
        }

        return ingredients
    }

}
