package tech.mercantec.easyeat.helpers

import android.content.Context
import android.util.Log
import kotlinx.serialization.Serializable

@Serializable
data class LoginRequest(val emailUsr: String, val password: String)

@Serializable
data class LoginResponse(val token: String, val userName: String, val id: Int, val refreshToken: String)

fun login(ctx: Context, email: String, password: String) {
    val request = LoginRequest(email, password)

    val response = requestJson<LoginRequest, LoginResponse>(ctx, "POST", "/api/User/login", request)

    with (ctx.getSharedPreferences("easyeat", Context.MODE_PRIVATE).edit()) {
        putInt("user-id", response.id)
        putString("username", response.userName)
        putString("auth-token", response.token)
        putString("refresh-token", response.refreshToken)
        apply()
    }
}

@Serializable
data class CreateUserRequest(val email: String, val userName: String, val password: String)

fun register(ctx: Context, email: String, username: String, password: String) {
    val request = CreateUserRequest(email, username, password)

    requestJson<CreateUserRequest, Boolean>(ctx, "POST", "/api/User/create", request)
}

@Serializable
data class RefreshTokenRequest(val refreshToken: String)

@Serializable
data class RefreshTokenResponse(val token: String, val refreshToken: String)

fun refreshAuthToken(ctx: Context, refreshToken: String): Boolean {
    val response: RefreshTokenResponse
    try {
        response = requestJson<RefreshTokenRequest, RefreshTokenResponse>(
            ctx,
            "POST", "/api/User/refreshtoken",
            RefreshTokenRequest(refreshToken)
        )
    } catch (e: ApiRequestException) {
        if (e.message != null)
            Log.e("EasyEat", e.message!!)

        return false
    }

    with (ctx.getSharedPreferences("easyeat", Context.MODE_PRIVATE).edit()) {
        putString("auth-token", response.token)
        putString("refresh-token", response.refreshToken)
        apply()
    }

    return true
}

fun isLoggedIn(ctx: Context): Boolean {
    val prefs = ctx.getSharedPreferences("easyeat", Context.MODE_PRIVATE)
    val authToken = prefs.getString("auth-token", null)
    val refreshToken = prefs.getString("refresh-token", null) ?: return false

    if (authToken == null) {
        return refreshAuthToken(ctx, refreshToken)
    }

    return true
}

@Serializable
data class UserInfoResponse(val id: Int, val userName: String, val email: String)

fun getUserInfo(ctx: Context): UserInfoResponse {
    val response = requestJson<Unit, UserInfoResponse>(ctx, "GET", "/api/User/get", null)

    return response
}
